Vendored static assets
======================

Via: https://getbootstrap.com/docs/5.3/getting-started/download/ (https://github.com/twbs/bootstrap/releases/download/v5.3.3/bootstrap-5.3.3-dist.zip)

- ``bootstrap-5.3.3-dist/css/bootstrap.min.css``: css/bootstrap.min.css (sha256 3c8f27e6009ccfd710a905e6dcf12d0ee3c6f2ac7da05b0572d3e0d12e736fc8)
- ``bootstrap-5.3.3-dist/js/bootstrap.bundle.min.js``: js/bootstrap.bundle.min.js (sha256 0833b2e9c3a26c258476c46266e6877fc75218625162e0460be9a3a098a61c6c)
